@@ -120,7 +120,7 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
             xlplayer->playmode = PM_EJECTING;
             return;
             }
-         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, channels);
+         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, channels, 1.f);
          xlplayer_write_channel_data(xlplayer);
          }
       xlplayer->playmode = PM_EJECTING;
@@ -163,10 +163,10 @@ static void avcodecdecode_play(struct xlplayer *xlplayer)
             xlplayer->playmode = PM_EJECTING;
             return;
             }
-         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, channels);
+         xlplayer_demux_channel_data(xlplayer, src_data->data_out, src_data->output_frames_gen, channels, 1.f);
          }
       else
-         xlplayer_demux_channel_data(xlplayer, self->floatsamples, frames, channels);
+         xlplayer_demux_channel_data(xlplayer, self->floatsamples, frames, channels, 1.f);
       
       do {
          xlplayer_write_channel_data(xlplayer);
