@@ -17,13 +17,13 @@
 #   If not, see <http://www.gnu.org/licenses/>.
 */
 
-#define _GNU_SOURCE
+#include "gnusource.h"
+#include <stdio.h>
 #include <math.h>
 #include <assert.h>
 #include "dbconvert.h"
 #include "compressor.h"
-
-#include <stdio.h>
+#include "bsdcompat.h"
 
 /*#define GNUPLOT*/
 
