@@ -17,10 +17,7 @@
 #   If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "../config.h"
-
-#define _POSIX_C_SOURCE 199309
-#define _GNU_SOURCE
+#include "gnusource.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -30,6 +27,8 @@
 #include "sourceclient.h"
 #include "live_ogg_encoder.h"
 #include "live_mp3_encoder.h"
+#include "live_oggflac_encoder.h"
+#include "bsdcompat.h"
 
 #define RS_INPUT_SAMPLES 512
 
@@ -254,22 +253,6 @@ void encoder_ip_data_free(struct encoder_ip_data *id)
    free(id);
    }
 
-void encoder_mark_final_packet(struct encoder *self, struct encoder_op_packet *packet)
-   {
-   /* on Ogg files this marks the final ogg_page as EOS (end of stream) */
-   if (self->mark_final_packet)
-      self->mark_final_packet(self, packet);
-   }
-
-void encoder_make_empty_packet(struct encoder *self, struct encoder_op_packet *packet)
-   {
-   /* on Ogg files this makes the packet be empty and EOS also is set */
-   if (self->make_empty_packet)
-      self->make_empty_packet(self, packet);
-   else
-      packet->header.data_size = 0;
-   }
-
 /* note encoder.mutex must be locked before helper threads can safely traverse 
    encoder.output_chain to find the op structure to pass to this function */
 size_t encoder_write_packet(struct encoder_op *op, struct encoder_op_packet *packet)
@@ -480,14 +463,26 @@ int encoder_start(struct threads_info *ti, struct universal_vars *uv, void *othe
          break;
 #endif /* HAVE_LAME */
       case DF_JACK_OGG:
-         encoder_init = live_ogg_encoder_init;
-         break;
+         if (!strcmp(ev->subformat, "vorbis"))
+            {
+            encoder_init = live_ogg_encoder_init;
+            break;
+            }
+#ifdef HAVE_OGGFLAC
+         if (!strcmp(ev->subformat, "flac"))
+            {
+            encoder_init = live_oggflac_encoder_init;
+            break;
+            }
+#endif
       /*case DF_FILE_MP3:
          encoder_init = file_mp3_encoder_init;
          break;
       case DF_FILE_OGG:
          encoder_init = file_ogg_encoder_init;
          break;*/
+         fprintf(stderr, "encoder_start: unhandled ogg format %s\n", ev->subformat);
+         goto failed;
       case DF_UNHANDLED:
       default:
          fprintf(stderr, "encoder_start: unhandled file format %s:%s\n", ev->format, ev->encode_source);
