@@ -45,11 +45,14 @@ struct encoder_vars
    char *sample_rate;
    char *resample_quality;
    char *format;
+   char *subformat;
    char *bit_rate;
    char *bit_rate_min;
    char *bit_rate_max;
+   char *bit_width;
    char *stereo;
    char *encode_quality;
+   char *use_metadata;
    char *filename;		/* for streaming a pre-recorded file */
    char *offset;
    char *metaformat;		/* extra/replacement information to use for metadata */
@@ -63,7 +66,7 @@ struct encoder_vars
 
 struct encoder_ip_data
    {
-   int caller_supplied_buffer;
+   int caller_supplied_buffer;   /* indicator of self ownership of buffers */
    int channels;
    size_t qty_samples;
    float *buffer[2];
@@ -143,10 +146,6 @@ struct encoder
    int oggserial;		/* n.b. not restricted to ogg useage */
    double timestamp;		/* running counter in seconds for current serial */
    void (*run_encoder)(struct encoder *);	/* pointer to the encoder in use */
-   void (*mark_final_packet)(struct encoder *, struct encoder_op_packet *);
-   				/* for marking a packet as being the final one */
-   void (*make_empty_packet)(struct encoder *, struct encoder_op_packet *);
-   	/* uses the penultimate packet as a template for a final empty packet */
    void *encoder_private;		/* used by the specific encoder */
    };
 
@@ -164,8 +163,6 @@ int encoder_stop(struct threads_info *ti, struct universal_vars *uv, void *other
 int encoder_update(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_new_metadata(struct threads_info *ti, struct universal_vars *uv, void *other);
 int encoder_new_metaformat(struct threads_info *ti, struct universal_vars *uv, void *other);
-void encoder_mark_final_packet(struct encoder *self, struct encoder_op_packet *packet);
-void encoder_make_empty_packet(struct encoder *self, struct encoder_op_packet *packet);
 void encoder_src_data_cleanup(struct encoder *self);
 struct encoder_ip_data *encoder_get_input_data(struct encoder *encoder, int min_samples_needed, int max_samples, float **caller_supplied_buffer);
 void encoder_ip_data_free(struct encoder_ip_data *id);
