@@ -17,8 +17,7 @@
 #   If not, see <http://www.gnu.org/licenses/>.
 */
 
-#define _GNU_SOURCE
-#include <../config.h>
+#include "gnusource.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
@@ -41,18 +40,20 @@
 #include "noisegate.h"
 #include "xlplayer.h"
 #include "ialloc.h"
-#include "vorbinfo.h"
 #include "mp4tag.h"
+#include "speextag.h"
 #include "sndfileinfo.h"
 #include "avcodecdecode.h"
+#include "oggdec.h"
+#include "bsdcompat.h"
 
 #define TRUE 1
 #define FALSE 0
 
-/* size of the ringbuffer (roughly one second) in bytes */
-#define RB_SIZE 262144
+/* playlength of ring buffer contents */
+#define RB_SIZE 1.0
 /* number of samples in the fade (ring) buffer */
-#define FB_SIZE (RB_SIZE / sizeof (float))
+#define FB_SIZE (RB_SIZE * sr)
 
 /* the different VOIP modes */
 #define NO_PHONE 0
@@ -219,7 +220,7 @@ struct xlplayer *plr_l, *plr_r, *plr_j, *plr_i; /* pipe reader instance stucture
 char *mixer_string, *compressor_string, *gate_string, *microphone_string;
 char *normalizer_string;
 char *micl, *micr, *auxl, *auxr, *audl, *audr, *strl, *strr, *action;
-char *oggpathname, *sndfilepathname, *mp4pathname, *mp4taglist, *avformatpathname;
+char *oggpathname, *sndfilepathname, *mp4pathname, *mp4taglist, *avformatpathname, *speexpathname, *speextaglist, *speexcreatedby;
 char *playerpathname, *seek_s, *size, *playerplaylist, *loop, *resamplequality;
 
 /* dictionary look-up type thing used by the parse routine */
@@ -244,9 +245,12 @@ struct kvpdict kvpdict[] = {
          { "STRR", &strr },
          { "OGGP", &oggpathname },
          { "MP4P", &mp4pathname },
+         { "SPXP", &speexpathname },
          { "SNDP", &sndfilepathname },
          { "AVFP", &avformatpathname },
          { "MP4T", &mp4taglist },
+         { "SPXT", &speextaglist },
+         { "SPXC", &speexcreatedby },
          { "RSQT", &resamplequality },
          { "ACTN", &action },			/* Action to take */
          { "", NULL }};
@@ -314,7 +318,7 @@ void handle_mute_button(sample_t *gainlevel, int switchlevel)
       {
       if (*gainlevel < 0.99F)		/* switching on */
          {
-         *gainlevel += (1.0F - *gainlevel) * 0.09F;
+         *gainlevel += (1.0F - *gainlevel) * 0.09F * 44100.0F / sr;
          if (*gainlevel >= 0.99F)
             *gainlevel = 1.0F;
          }
@@ -323,7 +327,7 @@ void handle_mute_button(sample_t *gainlevel, int switchlevel)
       {
       if (*gainlevel > 0.0F)		/* switching off */
          {
-         *gainlevel -= *gainlevel * 0.075F * (2.0F - *gainlevel) * (2.0F - *gainlevel);
+         *gainlevel -= *gainlevel * 0.075F * (2.0F - *gainlevel) * (2.0F - *gainlevel) * 44100.0F / sr;
          if (*gainlevel < 0.00002)
             *gainlevel = 0.0F;
          }
@@ -442,7 +446,7 @@ void update_smoothed_volumes()
    mic_target = ((lmic_on || rmic_on) ? -1.0F : 0.0F) * headroom_db;
    if ((diff = mic_target - current_headroom))
       {
-      current_headroom += diff * 0.0666666;
+      current_headroom += diff * 0.0666666 * 44100.0 / sr;
       if (mic_target)
          {
          if (diff > -0.00001F)
@@ -470,8 +474,8 @@ void update_smoothed_volumes()
 /* update_mic_and_aux: provide gradual mute/unmute for mic and aux buttons */
 void update_mic_and_aux()	/* mic and aux mute/unmute smoothing */
    {
-   const sample_t onfactor = 0.0006F;
-   const sample_t offfactor = 0.00028F;
+   const sample_t onfactor = 0.0006F * 44100.0F / (float)sr;
+   const sample_t offfactor = 0.00028F * 44100.0F / (float)sr;
    const sample_t upper = 0.999999;	/* these values are to prevent cpu usage going ^^^^ */
    const sample_t lower = 0.0000004;	/* -120 dB */
    
@@ -1585,7 +1589,7 @@ void interrupt_handler(int data)	/* eats the first ^C */
       if (count == 1)
          fprintf(stderr, "Mixer got ^C interrupt.\n");
       /* ignore this interrupt and wait instead for idjc to clean exit */
-      sigdelset(&mixersigset, SIGINT);
+      //sigdelset(&mixersigset, SIGINT);
       }
    }
 
@@ -1605,10 +1609,10 @@ void alarm_handler(int data)
    {
    struct xlplayer *cause;
    
-   if ((cause = plr_l)->watchdog_timer++ == 4 ||
-       (cause = plr_r)->watchdog_timer++ == 4 ||
-       (cause = plr_i)->watchdog_timer++ == 4 ||
-       (cause = plr_j)->watchdog_timer++ == 4) 
+   if ((cause = plr_l)->watchdog_timer++ == 9 ||
+       (cause = plr_r)->watchdog_timer++ == 9 ||
+       (cause = plr_i)->watchdog_timer++ == 9 ||
+       (cause = plr_j)->watchdog_timer++ == 9) 
       {
       if (cause->playmode == PM_INITIATE)
          {
@@ -1631,10 +1635,10 @@ void atexit_handler()
 void send_metadata_update(struct xlp_dynamic_metadata *dm)
    {
    pthread_mutex_lock(&(dm->meta_mutex));
-   fprintf(stderr, "dm->data_type = %d\n", dm->data_type);
-   if (dm->data_type < DM_JOINED_UC)
+   fprintf(stderr, "new dynamic metadata\n");
+   if (dm->data_type != DM_JOINED_UC)
       {
-      fprintf(stdout, "new_metadata=d%d:%sd%d:%sd%d:%sd9:%09dd9:%09dx\n", strlen(dm->artist), dm->artist, strlen(dm->title), dm->title, strlen(dm->artist_title), dm->artist_title, dm->current_audio_context, dm->rbdelay);
+      fprintf(stdout, "new_metadata=d%d:%sd%d:%sd%d:%sd9:%09dd9:%09dx\n", (int)strlen(dm->artist), dm->artist, (int)strlen(dm->title), dm->title, (int)strlen(dm->artist_title), dm->artist_title, dm->current_audio_context, dm->rbdelay);
       }
    else
       {
@@ -1671,11 +1675,6 @@ int main(int argc, char **argv)
 
    setenv("LC_ALL", "C", 1);		/* ensure proper sscanf operation */
 
-   if (sigfillset(&mixersigset))
-      {
-      fprintf(stderr, "sigfillset failed\n");
-      return 1;
-      }
    signal(SIGINT, interrupt_handler);
    signal(SIGALRM, alarm_handler); 
    signal(SIGSEGV, segfault_handler);
@@ -1827,7 +1826,7 @@ int main(int argc, char **argv)
       plr_j->fadeindex = FB_SIZE;
       plr_i->fadeindex = FB_SIZE;
       for (i = 0; i < FB_SIZE; i ++)
-         fade_table[i] = pow10f(i / -20000.0);
+         fade_table[i] = pow10f(i / -20000.0 * 44100.0 / FB_SIZE);
       }
          
    nframes = jack_get_sample_rate (client);
@@ -1846,9 +1845,9 @@ int main(int argc, char **argv)
    jp_lcf = ialloc(nframes);
    jp_rcf = ialloc(nframes);
    ip_lcf = ialloc(nframes);
-   ip_rcf = ialloc(nframes);   
-         
-   if (!(lp_lc && lp_rc && rp_lc && rp_rc && jp_lc && jp_rc && ip_lc && ip_rc &&         
+   ip_rcf = ialloc(nframes);
+
+   if (!(lp_lc && lp_rc && rp_lc && rp_rc && jp_lc && jp_rc && ip_lc && ip_rc &&
        lp_lcf && lp_rcf && rp_lcf && rp_rcf && jp_lcf && jp_rcf && ip_lcf && ip_rcf))
       {
       fprintf(stderr, "Failed to allocate read-buffers for player_reader reading\n");
@@ -1963,7 +1962,7 @@ int main(int argc, char **argv)
       
       if (!strcmp(action, "ogginforequest"))
          {
-         if (vorbinfo(oggpathname, &artist, &title, &length))
+         if (oggdecode_get_metainfo(oggpathname, &artist, &title, &length))
             {
             fprintf(stdout, "OIR:ARTIST=%s\nOIR:TITLE=%s\nOIR:LENGTH=%f\nOIR:end\n", artist, title, length);
             fflush(stdout);
@@ -1994,6 +1993,13 @@ int main(int argc, char **argv)
 #endif
 #endif
 
+#ifdef HAVE_SPEEX
+      if (!(strcmp(action, "speexreadtagrequest")))
+         speex_tag_read(speexpathname);
+      if (!(strcmp(action, "speexwritetagrequest")))
+         speex_tag_write(speexpathname, speexcreatedby, speextaglist);
+#endif
+
       if (!strcmp(action, "micmixstats"))
          {
 	 if (sscanf(microphone_string, ":%d:%d:%d:%d:%d:%d:%d:%f:%d:", &mic_filter,
@@ -2177,7 +2183,7 @@ int main(int argc, char **argv)
       if (!strcmp(action, "remakestrl"))
          {
 	 jack_port_disconnect(client, stream_left_port);
-	 jack_connect(client, "idjc-mx:str_lt", "idjc-sc:lt_in");	/* this is kludgy */
+         jack_connect(client, "idjc-mx:str_lt", "idjc-sc:lt_in");
 	 if (strcmp(strl, "default"))
             {
             if (strl[0] != '\0')
