@@ -104,19 +104,6 @@ static void live_ogg_build_metadata(struct encoder *encoder, struct loe_data *s)
    fprintf(stderr, "live_ogg_build_metadata: metadata for encoder %d\nartist=%s\ntitle=%s\n", encoder->numeric_id, s->artist, s->title);
    }
 
-static void live_ogg_mark_final_packet(struct encoder *encoder, struct encoder_op_packet *op)
-   {
-   ogg_page og;
-   
-   og.header = op->data;
-   og.header_len = og.header[26] + 27;
-   og.body = og.header + og.header_len;
-   og.body_len = op->header.data_size - og.header_len;
-   og.header[5] |= 0x4;			/* set the end of stream flag */
-   ogg_page_checksum_set(&og);
-   fprintf(stderr, "live_ogg_mark_final_packet: final Ogg page EOS has been set\n");
-   }
-
 static int live_ogg_write_packet(struct encoder *encoder, ogg_page *op, int flags)
    {
    struct encoder_op_packet packet;
@@ -244,8 +231,8 @@ static void live_ogg_encoder_main(struct encoder *encoder)
             oldgranulepos = s->os.granulepos;
             ogg_stream_packetin(&s->os, &s->op);
             s->pagesamples += s->os.granulepos - oldgranulepos;
-            /* write out a new ogg page at least 5 times a second */
-            if (s->pagesamples > encoder->samplerate / 5)
+            /* write out a new ogg page at least 10 times a second */
+            if (s->pagesamples > encoder->samplerate / 10)
                s->owf = ogg_stream_flush;
             while (s->owf(&s->os, &s->og))
                {
@@ -289,7 +276,6 @@ static void live_ogg_encoder_main(struct encoder *encoder)
    encoder->run_request_f = FALSE;
    encoder->encoder_state = ES_STOPPED;
    encoder->run_encoder = NULL;
-   encoder->mark_final_packet = NULL;
    encoder->flush = FALSE;
    encoder->encoder_private = NULL;
    free(s);
@@ -309,7 +295,6 @@ int live_ogg_encoder_init(struct encoder *encoder, struct encoder_vars *ev)
    s->max_bitrate = atol(ev->bit_rate_max);
    s->min_bitrate = atol(ev->bit_rate_min);
    encoder->encoder_private = s;
-   encoder->mark_final_packet = live_ogg_mark_final_packet;
    encoder->run_encoder = live_ogg_encoder_main;
    return SUCCEEDED;
    }
