@@ -34,10 +34,8 @@ struct loe_data
    ogg_stream_state os;
    ogg_page	    og;
    ogg_packet	    op;
-   float *infrastart;
-   float *infraend;
-   float *infra_ptr;
-   struct encoder_header_buffer ehb;
+   int pagesamples;
+   int (*owf)(ogg_stream_state *os, ogg_page *og);
    };
 
 int live_ogg_encoder_init(struct encoder *encoder, struct encoder_vars *ev);
