@@ -20,6 +20,7 @@
 #include "../config.h"
 #ifdef HAVE_MAD
 
+#include <jack/ringbuffer.h>
 #include "xlplayer.h"
 #include "mp3tagread.h"
 
@@ -37,6 +38,9 @@ struct mp3decode_vars
    int samplerate;
    struct mp3taginfo taginfo;
    struct chapter *current_chapter;
+   jack_ringbuffer_t *lrb;
+   jack_ringbuffer_t *rrb;
+   int initial_data;
    };
 
 int mp3decode_reg(struct xlplayer *xlplayer);
