@@ -20,11 +20,12 @@
 #include "../config.h"
 #ifdef HAVE_MAD
 
-#define _GNU_SOURCE
+#include "gnusource.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "mp3tagread.h"
+#include "bsdcompat.h"
 
 #if 0
 static void unsynchronise(struct mp3decode_id3data *us)
