@@ -587,7 +587,7 @@ int recorder_start(struct threads_info *ti, struct universal_vars *uv, void *oth
          break;
       case DF_JACK_OGG:
       case DF_FILE_OGG:
-         file_extension = ".ogg";
+         file_extension = ".oga";
          break;
       default:
          fprintf(stderr, "recorder_start: data_format is not set to a handled value\n");
@@ -613,8 +613,8 @@ int recorder_start(struct threads_info *ti, struct universal_vars *uv, void *oth
       return FAILED;
       }
    self->initial_serial = encoder_client_set_flush(self->encoder_op) + 1;
-   if (file_extension == ".ogg")
-      recorder_write_ogg_metaheader(self);
+   //if (file_extension == ".oga")
+   //   recorder_write_ogg_metaheader(self);
    fprintf(stderr, "streamer_main: connected to server - awaiting serial %d\n", self->initial_serial);
    if (self->pause_request == TRUE)
       self->record_mode = RM_PAUSED;
