@@ -86,10 +86,10 @@ static void sndfiledecode_play(struct xlplayer *xlplayer)
          xlplayer->playmode = PM_EJECTING;
          return;
          }
-      xlplayer_demux_channel_data(xlplayer, xlplayer->src_data.data_out, xlplayer->src_data.output_frames_gen, self->sf_info.channels);
+      xlplayer_demux_channel_data(xlplayer, xlplayer->src_data.data_out, xlplayer->src_data.output_frames_gen, self->sf_info.channels, 1.f);
       }
    else
-      xlplayer_demux_channel_data(xlplayer, self->flbuf, sf_count, self->sf_info.channels);
+      xlplayer_demux_channel_data(xlplayer, self->flbuf, sf_count, self->sf_info.channels, 1.f);
    xlplayer_write_channel_data(xlplayer);
    if (sf_count == 0)
       {
