@@ -199,10 +199,13 @@ int main()
       { "sample_rate",      &ev.sample_rate },
       { "resample_quality", &ev.resample_quality },
       { "format", 	    &ev.format },
+      { "subformat",        &ev.subformat },
       { "bit_rate", 	    &ev.bit_rate },
       { "bit_rate_min",     &ev.bit_rate_min },
       { "bit_rate_max",     &ev.bit_rate_max },
+      { "bit_width",        &ev.bit_width },
       { "stereo", 	    &ev.stereo },
+      { "use_metadata",     &ev.use_metadata },
       { "encode_quality",   &ev.encode_quality },
       { "filename", 	    &ev.filename },
       { "offset", 	    &ev.offset },
