@@ -17,7 +17,7 @@
 #   If not, see <http://www.gnu.org/licenses/>.
 */
 
-#define _GNU_SOURCE
+#include "gnusource.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -27,13 +27,15 @@
 #include <jack/jack.h>
 #include <jack/ringbuffer.h>
 #include <samplerate.h>
+
 #include "xlplayer.h"
 #include "mp3dec.h"
-#include "vorbisdec.h"
+#include "oggdec.h"
 #include "flacdecode.h"
 #include "sndfiledecode.h"
 #include "mp4decode.h"
 #include "avcodecdecode.h"
+#include "bsdcompat.h"
 
 #define TRUE 1
 #define FALSE 0
@@ -96,7 +98,7 @@ float *xlplayer_make_audio_to_float(struct xlplayer *self, float *buffer, uint8_
 
 /* get_next_gain: compute the gain of the next sample */
 /* used to fade in the audio when not starting from the beginning */
-inline sample_t xlplayer_get_next_gain(struct xlplayer *self)
+sample_t xlplayer_get_next_gain(struct xlplayer *self)
    {
    if (self->fadein_index >= 0)
       {
@@ -112,7 +114,7 @@ inline sample_t xlplayer_get_next_gain(struct xlplayer *self)
    }
 
 /* xlplayer_demux_channel_data: this is where down/upmixing is performed - audio split to 2 channels */
-void xlplayer_demux_channel_data(struct xlplayer *self, sample_t *buffer, int num_samples, int num_channels)
+void xlplayer_demux_channel_data(struct xlplayer *self, sample_t *buffer, int num_samples, int num_channels, float scale)
    {
    int i;
    sample_t *lc, *rc, *src, gain;
@@ -136,7 +138,7 @@ void xlplayer_demux_channel_data(struct xlplayer *self, sample_t *buffer, int nu
          for (lc = self->leftbuffer, src = buffer, i = 0; i < num_samples; i++)
             {
             gain = xlplayer_get_next_gain(self);	/* used for fade-in */
-            *lc++ = *src++ * gain;
+            *lc++ = *src++ * gain * scale;
             }
          memcpy(self->rightbuffer, self->leftbuffer, self->op_buffersize);
          break;
@@ -144,42 +146,42 @@ void xlplayer_demux_channel_data(struct xlplayer *self, sample_t *buffer, int nu
          for (lc = self->leftbuffer, rc = self->rightbuffer, src = buffer, i = 0; i < num_samples; i++)
             {
             gain = xlplayer_get_next_gain(self);
-            *lc++ = *src++ * gain;	/* stereo mix is a simple demultiplex job */
-            *rc++ = *src++ * gain;
+            *lc++ = *src++ * gain * scale;	/* stereo mix is a simple demultiplex job */
+            *rc++ = *src++ * gain * scale;
             }
          break;
       case 3:
          for (lc = self->leftbuffer, rc = self->rightbuffer, src = buffer, i = 0; i < num_samples; i++)
             {
             gain = xlplayer_get_next_gain(self) * 0.5F;
-            *lc = (*src++) * gain;	/* do the left and right channels */
-            *rc = (*src++) * gain;
-            *(lc++) += (*src) *gain;	/* downmix the middle channel to the left and right one */
-            *(rc++) += (*src++) *gain;
+            *lc = (*src++) * gain * scale; /* do the left and right channels */
+            *rc = (*src++) * gain * scale;
+            *(lc++) += (*src) *gain * scale;	/* downmix the middle channel to the left and right one */
+            *(rc++) += (*src++) *gain * scale;
             }
          break;
       case 4:
          for (lc = self->leftbuffer, rc = self->rightbuffer, src = buffer, i = 0; i < num_samples; i++, src += 4)
             {
             gain = xlplayer_get_next_gain(self) * 0.5F;
-            *lc++ = (src[0] + src[3]) * gain;
-            *rc++ = (src[2] + src[4]) * gain;
+            *lc++ = (src[0] + src[3]) * gain * scale;
+            *rc++ = (src[2] + src[4]) * gain * scale;
             }
          break;
       case 5:
          for (lc = self->leftbuffer, rc = self->rightbuffer, src = buffer, i = 0; i < num_samples; i++, src += 5)
             {
             gain = xlplayer_get_next_gain(self) * 0.5F;
-            *lc++ = (src[0] + src[3]) * gain;	/* this is for 4.1 channels with sub discarded */
-            *rc++ = (src[2] + src[4]) * gain;
+            *lc++ = (src[0] + src[3]) * gain * scale;	/* this is for 4.1 channels with sub discarded */
+            *rc++ = (src[2] + src[4]) * gain * scale;
             }
          break;
       case 6:
          for (lc = self->leftbuffer, rc = self->rightbuffer, src = buffer, i = 0; i < num_samples; i++, src += 6)
             {
             gain = xlplayer_get_next_gain(self) * 0.33333333F;
-            *lc++ = (src[0] + src[3] + src[4]) * gain;	/* this is for 5.1 channels */
-            *rc++ = (src[2] + src[4] + src[5]) * gain;   /* sub discarded */
+            *lc++ = (src[0] + src[3] + src[4]) * gain * scale;	/* this is for 5.1 channels */
+            *rc++ = (src[2] + src[4] + src[5]) * gain * scale;   /* sub discarded */
             }
          break;
       }
@@ -234,7 +236,7 @@ static char *get_extension(char *pathname)
    {
    char *p, *extension;
    
-   if (!(p = rindex(pathname, '.')))
+   if (!(p = strrchr(pathname, '.')))
       {
       fprintf(stderr, "get_extension: failed to find a file extension delineator '.'\n");
       return strdup("");
@@ -290,7 +292,10 @@ static void *xlplayer_main(struct xlplayer *self)
             self->initial_audio_context = -1;	/* pre-select failure return code */
             extension = get_extension(self->pathname);
             if (
-	               (!strcmp(extension, "ogg") && vorbisdecode_reg(self))
+	            ((!strcmp(extension, "ogg") || !strcmp(extension, "oga")) && oggdecode_reg(self))
+#ifdef HAVE_SPEEX
+                    || (!strcmp(extension, "spx") && oggdecode_reg(self))
+#endif
 #ifdef HAVE_FLAC
 		    || (!strcmp(extension, "flac") && flacdecode_reg(self))
 #endif
@@ -309,16 +314,16 @@ static void *xlplayer_main(struct xlplayer *self)
 	       )
 	       {
                self->playmode = PM_PLAYING;
-               self->dec_init(self);
+               self->play_progress_ms = 0;
                self->write_deferred = 0;
                self->pause = 0;
                self->samples_written = 0;
                self->sleep_samples = 0;
                self->fadein_index = self->seek_s ? 0 : -1;
+               self->dec_init(self);
                if (self->command != CMD_COMPLETE)
                   ++self->current_audio_context;
                self->initial_audio_context = self->current_audio_context;
-               self->play_progress_ms = 0;
                }
             else
                self->playmode = PM_STOPPED;
@@ -332,7 +337,6 @@ static void *xlplayer_main(struct xlplayer *self)
                self->dec_play(self);
             break;
          case PM_EJECTING:
-            self->play_progress_ms = 0;
             self->dec_eject(self);
             if (self->playlistmode)
                {
@@ -450,7 +454,7 @@ static long conv_rf_read(void *cb_data, float **audiodata)
       }
    }
 
-struct xlplayer *xlplayer_create(int samplerate, size_t rbsize, char *playername, int *shutdown_f)
+struct xlplayer *xlplayer_create(int samplerate, double duration, char *playername, int *shutdown_f)
    {
    struct xlplayer *self;
    int error;
@@ -460,24 +464,24 @@ struct xlplayer *xlplayer_create(int samplerate, size_t rbsize, char *playername
       fprintf(stderr, "xlplayer: malloc failure");
       exit(5);
       }
-   self->rbsize = rbsize;
-   self->rbdelay = (rbsize >> 2) * 1000 / samplerate;
-   if (!(self->left_ch = jack_ringbuffer_create(rbsize)))
+   self->rbsize = (int)(duration * samplerate) << 2;
+   self->rbdelay = (int)(duration * 1000);
+   if (!(self->left_ch = jack_ringbuffer_create(self->rbsize)))
       {
       fprintf(stderr, "xlplayer: ringbuffer creation failure");
       exit(5);
       }
-   if (!(self->right_ch = jack_ringbuffer_create(rbsize)))
+   if (!(self->right_ch = jack_ringbuffer_create(self->rbsize)))
       {
       fprintf(stderr, "xlplayer: ringbuffer creation failure");
       exit(5);
       }
-   if (!(self->left_fade = jack_ringbuffer_create(rbsize)))
+   if (!(self->left_fade = jack_ringbuffer_create(self->rbsize)))
       {
       fprintf(stderr, "xlplayer: ringbuffer creation failure");
       exit(5);
       }
-   if (!(self->right_fade = jack_ringbuffer_create(rbsize)))
+   if (!(self->right_fade = jack_ringbuffer_create(self->rbsize)))
       {
       fprintf(stderr, "xlplayer: ringbuffer creation failure");
       exit(5);
@@ -580,6 +584,7 @@ int xlplayer_play(struct xlplayer *self, char *pathname, int seek_s, int size)
    self->seek_s = seek_s;
    self->size = size;
    self->loop = FALSE;
+   self->usedelay = FALSE;
    self->playlistmode = FALSE;
    self->command = CMD_PLAY;
    while (self->command)
@@ -880,6 +885,6 @@ void xlplayer_set_dynamic_metadata(struct xlplayer *xlplayer, enum metadata_t ty
    dm->artist_title = strdup(artist_title);
    dm->current_audio_context = xlplayer->current_audio_context;
    min = (xlplayer->rbdelay < xlplayer->play_progress_ms) ? xlplayer->rbdelay : xlplayer->play_progress_ms;
-   dm->rbdelay = min * usedelay;
+   dm->rbdelay = min * usedelay * 9 / 10;
    pthread_mutex_unlock(&(dm->meta_mutex));
    }
