@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <samplerate.h>
 #include <sndfile.h>
-#include <vorbis/vorbisfile.h>
 
 #ifdef HAVE_FLAC
 #include <FLAC/all.h>
@@ -46,7 +45,7 @@ enum command_t {CMD_COMPLETE, CMD_PLAY, CMD_EJECT, CMD_CLEANUP, CMD_THREADEXIT,
 
 enum playmode_t {PM_STOPPED, PM_INITIATE, PM_PLAYING, PM_EJECTING };
 
-enum metadata_t {DM_NONE_NEW, DM_SPLIT_U8, DM_JOINED_U8, DM_SPLIT_L1, DM_JOINED_L1, DM_JOINED_UC, DM_JOINED_UCBE};
+enum metadata_t {DM_NONE_NEW, DM_SPLIT_U8, DM_JOINED_U8, DM_SPLIT_L1, DM_JOINED_L1, DM_JOINED_UC, DM_JOINED_UCBE, DM_NOTAG};
 
 struct xlp_dynamic_metadata	/* song titles can change mid-file */
    {				/* this structure facilitates transmission */
@@ -125,10 +124,11 @@ struct xlplayer
    void (*dec_play)(struct xlplayer *);	/* function that decodes one frame of audio data */
    void (*dec_eject)(struct xlplayer *);/* function that cleans up after the decoder */
    struct xlp_dynamic_metadata dynamic_metadata;
+   int usedelay;                        /* client to delay dynamic metadata display */
    };
 
 /* xlplayer_create: create an instance of the player */
-struct xlplayer *xlplayer_create(int samplerate, size_t ringbuffersize, char *playername, int *shutdown_f);
+struct xlplayer *xlplayer_create(int samplerate, double duration, char *playername, int *shutdown_f);
 /* xlplayer_destroy: the opposite of xlplayer_create */
 void xlplayer_destroy(struct xlplayer *);
 
@@ -176,13 +176,13 @@ int xlplayer_create_fadein_lookup(float size_seconds, int samplerate);
 void xlplayer_destroy_fadein_lookup(void);
 
 /* calculate the gain for fading in - used when seeking to prevent clicks */
-inline jack_default_audio_sample_t xlplayer_get_next_gain(struct xlplayer *self);
+jack_default_audio_sample_t xlplayer_get_next_gain(struct xlplayer *self);
 
 /* put audio data in format recognised by jack and libsamplerate */
 float *xlplayer_make_audio_to_float(struct xlplayer *self, float *buffer, uint8_t *data, int num_samples, int bits_per_sample, int num_channels);
 
 /* splits audio data into separate audio streams, ready for writing */
-void xlplayer_demux_channel_data(struct xlplayer *self, jack_default_audio_sample_t *buffer, int num_samples, int num_channels);
+void xlplayer_demux_channel_data(struct xlplayer *self, jack_default_audio_sample_t *buffer, int num_samples, int num_channels, float scale);
 
 /* cause the cached pcm data to be written out to the jack ringbuffer */
 void xlplayer_write_channel_data(struct xlplayer *self);
