@@ -15,12 +15,14 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+__all__ = ['jingles']
+
 import pygtk
 pygtk.require('2.0')
 import gtk, os, gobject
 from IDJCfree import *
 from idjc_config import *
-from langheader import *
+from ln_text import ln
 
 class jingles:
    def cleanup(self):
@@ -283,7 +285,7 @@ class jingles:
       self.parent = parent
       self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
       self.parent.window_group.add_window(self.window)
-      self.window.set_title(jingles_window_text)
+      self.window.set_title(ln.jingles_window)
       self.window.set_destroy_with_parent(True)
       self.window.set_border_width(8)
       self.window.connect("delete_event", self.delete_event)
@@ -312,7 +314,8 @@ class jingles:
       self.deckvol.set_draw_value(False)
       self.vboxvol.pack_start(self.deckvol, True, True, 0)
       self.deckvol.show()
-      self.vboxvol.show() 
+      self.vboxvol.show()
+      parent.tooltips.set_tip(self.deckvol, ln.jingles_volume_tip)
                 
            # A vertical box for our second volume control
       self.vboxinter = gtk.VBox()
@@ -337,6 +340,7 @@ class jingles:
       self.vboxinter.pack_start(self.intervol, True, True, 0)
       self.intervol.show()
       self.vboxinter.show()
+      parent.tooltips.set_tip(self.intervol, ln.wet_voice_volume_tip)
                 
       vbox = gtk.VBox()
       vbox.set_spacing(6)
@@ -376,12 +380,13 @@ class jingles:
       self.treeview.show()
       vbox.pack_start(scrolllist, True, True, 1)
       scrolllist.show()
+      parent.tooltips.set_tip(scrolllist, ln.jingles_playlist_tip)
       
       hbox = gtk.HBox()
       hbox.set_spacing(4)
       hbox.set_border_width(0)
       
-      label = gtk.Label(sequence_text)
+      label = gtk.Label(ln.sequence)
       hbox.pack_start(label, False, False, 0)
       label.show()
       
@@ -390,6 +395,7 @@ class jingles:
       self.entry.set_width_chars(10)
       hbox.pack_start(self.entry, True, True, 0)
       self.entry.show()
+      parent.tooltips.set_tip(self.entry, ln.jingles_entry_tip)
       
       vbox.pack_start(hbox, False, False, 0)
       hbox.show()
@@ -413,6 +419,7 @@ class jingles:
       self.play.connect("toggled", self.callback, "Play")
       hbox.pack_start(self.play, True, True, 0)
       self.play.show()
+      parent.tooltips.set_tip(self.play, ln.play_jingles_tip)
       
       pixbuf = gtk.gdk.pixbuf_new_from_file(pkgdatadir + "play3" + gfext)
       pixbuf = pixbuf.scale_simple(14, 14, gtk.gdk.INTERP_BILINEAR)
@@ -425,6 +432,7 @@ class jingles:
       self.play_ex.connect("toggled", self.callback, "PlayEx")
       hbox.pack_start(self.play_ex, True, True, 0)
       self.play_ex.show()
+      parent.tooltips.set_tip(self.play_ex, ln.playex_jingles_tip)
       
       image = gtk.Image()
       image.set_from_file(pkgdatadir + "stop" + gfext)
@@ -435,6 +443,7 @@ class jingles:
       self.stop.connect("clicked", self.callback, "Stop")
       hbox.pack_start(self.stop, True, True, 0)
       self.stop.show()
+      parent.tooltips.set_tip(self.stop, ln.stop_jingles_tip)
       
       pixbuf = gtk.gdk.pixbuf_new_from_file(pkgdatadir + "interlude" + gfext)
       pixbuf = pixbuf.scale_simple(49, 21, gtk.gdk.INTERP_BILINEAR)
@@ -446,11 +455,13 @@ class jingles:
       image.show()
       hbox.pack_start(self.interlude, True, True, 0)
       self.interlude.show()
+      parent.tooltips.set_tip(self.interlude, ln.wet_voice_player_tip)
       
       self.refresh = gtk.Button(None, gtk.STOCK_REFRESH)
       self.refresh.connect("clicked", self.callback, "Refresh")
       hbox.pack_start(self.refresh, True, True, 0)
       self.refresh.show()
+      parent.tooltips.set_tip(self.refresh, ln.refresh_jingles_tip)
       
       frame.add(hbox)
       hbox.show()
