@@ -17,6 +17,8 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+__all__ = ['multitag']
+
 import pygtk
 pygtk.require('2.0')
 import gtk, os, sys
@@ -26,7 +28,7 @@ except:
    eyeD3 = None
 from IDJCfree import *
 from idjc_config import *
-from langheader import *
+from ln_text import *
 
 class mp4tagger(gtk.VBox):
    def load_tag(self, pathname):
@@ -97,6 +99,34 @@ class mp4tagger(gtk.VBox):
       textview.set_justification(gtk.JUSTIFY_LEFT)
 
 class vorbistagger(gtk.VBox):
+   def load_speex_tag(self, pathname):
+      self.idjc.mixer_write("SPXP=%s\nACTN=speexreadtagrequest\nend\n" % pathname, True)
+      data = ""
+      while 1:
+         line = self.idjc.mixer_read()
+         if line == "":
+            print "mixer crashed during speex tag read operation"
+            return
+         if line == "idjcmixer: speexfileinfo Not Valid\n":
+            return
+         if line == "idjcmixer: speextagread end\n":
+            break
+         if line.startswith("idjcmixer: speextagread "):
+            data += line[24:]
+         if line.startswith("idjcmixer: speexcreatedread "):
+            self.createdby = line[28:]
+      kvplist = self.make_pairs(data)
+      recommended = [ u"author", u"title" ]
+      precede = u""
+      for recommend in recommended:
+         for key, value in kvplist:
+            if key == recommend:
+               break
+         else:
+            precede = precede + recommend + u"=\n"
+      self.textbuffer.set_text(precede + data)
+      print "creation string says:", self.createdby
+
    def load_ogg_tag(self, pathname):
       self.vc = os.getenv("vorbiscomment")
       if self.vc == "" or self.vc == None:
@@ -141,6 +171,18 @@ class vorbistagger(gtk.VBox):
             precede = precede + recommend + u"=\n"
       self.textbuffer.set_text(precede + data)
       
+   def save_speex_tag(self, pathname):
+      kvp = self.make_pairs()
+      text = u""
+      
+      self.idjc.mixer_write("SPXC=%s" % self.createdby) # contains '\n'
+      self.idjc.mixer_write("SPXT=\n")
+      for key, value in kvp:
+         self.idjc.mixer_write("+SPXT=" + key + "=" + value + "\n")
+      self.idjc.mixer_write("SPXP=" + pathname + "\n")
+      self.idjc.mixer_write("ACTN=speexwritetagrequest\nend\n", True)
+      print "speex tag saved"
+      
    def save_ogg_tag(self, pathname):
       if self.vc != "missing":
          kvp = self.make_pairs()
@@ -188,8 +230,9 @@ class vorbistagger(gtk.VBox):
                kvp.append((key.strip(), value.strip()))
       return kvp
 
-   def __init__(self, pathname):
+   def __init__(self, pathname, idjcroot):
       gtk.VBox.__init__(self)
+      self.idjc = idjcroot
       scrolled_window = gtk.ScrolledWindow()
       scrolled_window.set_size_request(350, 250)
       scrolled_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -334,7 +377,7 @@ class id3tagger(gtk.VBox):
       self.idjc_comment_desc = "idjc-comment"
       self.idjc_comment_lang = "XXX"
       
-      frame = gtk.Frame(" " + standard_tags_text + " ")
+      frame = gtk.Frame(" " + ln.standard_tags + " ")
       frame.set_border_width(6)
       gtk.VBox.pack_start(self, frame, False, False, 0)
       sthbox = gtk.HBox()
@@ -350,7 +393,7 @@ class id3tagger(gtk.VBox):
       sthbox.pack_start(strvbox, True, True, 1)
       strvbox.show()
       
-      title = gtk.Label(tag_title_text)
+      title = gtk.Label(ln.tag_title)
       stlvbox.add(title)
       title.show()
       
@@ -359,7 +402,7 @@ class id3tagger(gtk.VBox):
       strvbox.add(self.title)
       self.title.show()
       
-      artist = gtk.Label(tag_artist_text)
+      artist = gtk.Label(ln.tag_artist)
       stlvbox.add(artist)
       artist.show()
       
@@ -367,7 +410,7 @@ class id3tagger(gtk.VBox):
       strvbox.add(self.artist)
       self.artist.show()
       
-      album = gtk.Label(tag_album_text)
+      album = gtk.Label(ln.tag_album)
       stlvbox.add(album)
       album.show()
       
@@ -375,7 +418,7 @@ class id3tagger(gtk.VBox):
       strvbox.add(self.album)
       self.album.show()
       
-      track = gtk.Label(tag_track_text)
+      track = gtk.Label(ln.tag_track)
       stlvbox.add(track)
       track.show()
       
@@ -383,7 +426,7 @@ class id3tagger(gtk.VBox):
       strvbox.add(self.track)
       self.track.show()
       
-      year = gtk.Label(tag_year_text)
+      year = gtk.Label(ln.tag_year)
       stlvbox.add(year)
       year.show()
       
@@ -391,7 +434,7 @@ class id3tagger(gtk.VBox):
       strvbox.add(self.year)
       self.year.show()
       
-      genre = gtk.Label(tag_genre_text)
+      genre = gtk.Label(ln.tag_genre)
       stlvbox.add(genre)
       genre.show()
       
@@ -414,7 +457,7 @@ class id3tagger(gtk.VBox):
       strvbox.add(genre_box)
       genre_box.show()
       
-      comment = gtk.Label(tag_comment_text)
+      comment = gtk.Label(ln.tag_comment)
       stlvbox.add(comment)
       comment.show()
       
@@ -434,13 +477,14 @@ class multitag:
       idjcroot.player_right.update_playlist(newplaylistdata)
    
    def is_supported(self, pathname):
-      supported = [ "mp3", "ogg", "flac" ]
-      try:
-         if mp4enabled:
-            supported.append("mp4")
-            supported.append("m4a")
-      except:
-         pass
+      supported = [ "mp3", "ogg", "oga" ]
+      if mp4enabled:
+         supported.append("mp4")
+         supported.append("m4a")
+      if flacenabled:
+         supported.append("flac")
+      if speexenabled:
+         supported.append("spx")
       extension = os.path.splitext(pathname)[1][1:].lower()
       if supported.count(extension) != 1:
          print "File type", extension, "is not supported."
@@ -458,7 +502,7 @@ class multitag:
       self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
       if idjcroot is not None:
          idjcroot.window_group.add_window(self.window)
-      self.window.set_title(tagger_window_title_text)
+      self.window.set_title(ln.tagger_window_title)
       self.window.set_destroy_with_parent(True)
       self.window.set_border_width(9)
       self.window.set_resizable(True)
@@ -470,9 +514,9 @@ class multitag:
       vbox.show()
       label = gtk.Label()
       if idjcroot:
-         label.set_markup(u"<b>" + tagger_filename_text + u" " + rich_safe(unicode(os.path.split(pathname)[1], encoding).encode("utf-8", "replace")) + u"</b>")
+         label.set_markup(u"<b>" + ln.tagger_filename + u" " + rich_safe(unicode(os.path.split(pathname)[1], encoding).encode("utf-8", "replace")) + u"</b>")
       else:
-         label.set_markup(u"<b>" + tagger_filename_text + u" " + rich_safe(unicode(os.path.split(pathname)[1], "latin1").encode("utf-8", "replace")) + u"</b>")
+         label.set_markup(u"<b>" + ln.tagger_filename + u" " + rich_safe(unicode(os.path.split(pathname)[1], "latin1").encode("utf-8", "replace")) + u"</b>")
       vbox.pack_start(label, False, False, 6)
       label.show()
       
@@ -520,15 +564,18 @@ class multitag:
          self.id3.show()
          label.show()
       else:
-         self.vorbis = vorbistagger(pathname)
-         if extension == "ogg":
+         self.vorbis = vorbistagger(pathname, idjcroot)
+         if extension == "ogg" or extension == "oga":
             reload_button.connect_object("clicked", self.vorbis.load_ogg_tag, pathname)
             apply_button.connect_object("clicked", self.vorbis.save_ogg_tag, pathname)
+         elif extension == "spx":
+            reload_button.connect_object("clicked", self.vorbis.load_speex_tag, pathname)
+            apply_button.connect_object("clicked", self.vorbis.save_speex_tag, pathname)
          elif extension == "flac":
             reload_button.connect_object("clicked", self.vorbis.load_flac_tag, pathname)
             apply_button.connect_object("clicked", self.vorbis.save_flac_tag, pathname)
          reload_button.clicked()
-         label = gtk.Label(vorbis_tag_text)
+         label = gtk.Label(ln.vorbis_tag)
          notebook.append_page(self.vorbis, label)
          self.vorbis.show()
          label.show()
@@ -540,7 +587,7 @@ class multitag:
          else:
             reload_button.connect_object("clicked", self.id3.load_tag, pathname, extension)
             apply_button.connect_object("clicked", self.id3.save_tag, pathname)
-            label = gtk.Label(id3_tag_text)
+            label = gtk.Label(ln.id3_tag)
             notebook.append_page(self.id3, label)
             self.id3.show()
             label.show()
