@@ -126,7 +126,7 @@ comp_ratio = "Ratio"
 
 comp_relative = "Relative"
 
-comp_release = "Decay"
+comp_release = "Release"
 
 compression_meter_tip = "A meter indicating the current amount of attenuation being applied to each microphone input by the compressor."
 
@@ -194,13 +194,13 @@ dnr_compressor = "Dynamic Range Compressor"
 
 down_arrow_tip = "This moves the highlighted track down the playlist order."
 
-drc_attack_tip = "The speed at which signal attenuation is applied. Lower equals faster and equates to how much more attenuation is to be applied per audio sample as a fraction towards the computed ideal level. A very low number would be more responsive but will remove punchiness from the voice. A sensible setting would be 100."
+drc_attack_tip = "The speed at which signal attenuation is applied. Lower equals faster and is a time constant in milliseconds. A very low number would be more responsive but will remove punchiness from the voice. A sensible setting would be 2.25ms provided the 30ms RMS filter is in use."
 
 drc_deess_tip = "This reduces the impact of S T and P sounds by providing a second audio signal path to the compressor which performs a kind of audio processing to isolate those sounds. The higher the De-ess figure the more dominant this second audio path becomes. Making a test recording is the best way to find the ideal level however values above 10 are probably not sensible but are included for illustrating the full effect."
 
-drc_depth_tip = "This provides what is known as soft knee compression so that the compression ratio ramps up gradually with an increasing audio level rather than suddenly being applied at the 'Knee' point. This makes for a more natural sound and is recommended for compressing the human voice. A sensible value would be 27. Use 0 if you want to use hard knee compression instead. It is recommended to set this value before calibrating 'Knee' since the two interact with one another."
+drc_depth_tip = "When the setting is anything other than zero, this feature provides what is known as soft knee compression so that the compression ratio ramps up gradually with an increasing audio level rather than suddenly being applied at the 'Knee' point. This makes for a more natural sound and is recommended for compressing the human voice. A sensible value would be 27. Using 0 results in what is known in compressor jargon as hard knee compression. It is recommended to set this value before calibrating 'Knee' since there is interaction between the two settings."
 
-drc_ducking_hold_tip = "This controls the number of audio samples that need to pass before ducking is released. A sensible figure would be 30000 but the ideal figure depends on your speaking style."
+drc_ducking_hold_tip = "This is the time delay in milliseconds before ducking attenuation starts to be released. A sensible figure would be 680ms but the ideal figure depends to some extent on your speaking style."
 
 drc_ducking_ratio_tip = "Ducking is a feature that reduces the sound level of the music players when the DJ is talking with the microphone on. This allows the DJ to talk over the music with ease and works by taking the amount of signal attenuation applied by the compressor and multiplying it by the ducking factor (note: this widget controls the ducking factor) to calculate a level of attenuation to apply to the music players. A sensible level would be 1.6 but it largely depends on how much compression you are using."
 
@@ -218,7 +218,7 @@ drc_knee_tip = "The audio signal level in dB above which the full amount of comp
 
 drc_ratio_tip = "Adjusts the compression ratio applied to the microphone input. The bigger the number the more compressed the sound. A sensible value for this would be 3 or 3.5. To deactivate this feature choose 0. Consult the web for more information on the subject of 'dynamic range compression'."
 
-drc_release_tip = "Decay is the opposite of attack and is also commonly called release and relates to how quickly the compressor releases signal attenuation when the microphone signal level drops. The higher this figure the longer it takes. A sensible setting would be 8000. Too high a figure will result in an audio artifact known as compressor pump where the sound level changes in a notably rhythmic fashion."
+drc_release_tip = "Release is the opposite of attack and relates to how quickly the compressor releases signal attenuation when the microphone signal level drops. The higher this figure the longer it takes. A sensible setting would be 180ms. Too high a figure will result in an audio artifact known as compressor pump where the sound level changes in a notably rhythmic fashion."
 
 duplicate = "Duplicate"
 
@@ -248,10 +248,6 @@ event_tab = "Event"
 
 exchange = "Exchange"
 
-extm3u = "Process the metadata in extended m3u files"
-
-extm3u_tip = "This feature is either useful or a hindrance depending on the quality of the information provided within the m3u files concerned. When this feature is turned off metadata is obtained from the media files instead. It also affects whether the m3u files will be extended or not when saving playlists."
-
 fadeout_toggle = "Fadeout"
 
 fall = "Fall"
@@ -260,6 +256,8 @@ fast_resample = "Fast"
 
 fastest_resample = "Fastest"
 
+feature_disabled = "Feature Disabled"
+
 feature_set = "Feature Set"
 
 filter_fast = "3ms RMS"
@@ -268,8 +266,24 @@ filter_slow = "30ms RMS"
 
 finish = "Finish"
 
+flac_bitrates = ("16 Bit", "20 Bit", "24 Bit")
+
+flac16_tip = "The ideal bit width for streaming assuming you have the bandwidth to spare."
+
+flac20_tip = "Ideal for very high quality streaming or recording although not as compatible as 16 bit."
+
+flac24_tip = "The highest quality audio format available within IDJC. Recommended for pre-recording."
+
+flacmetadata = "Metadata"
+
+flac_streamtab_tip = "This chooses the OggFLAC format for streaming and recording."
+
+flacmetadata_tip = "You can prevent the sending of metadata by turning this feature off. This will prevent certain players from dropping the stream or inserting an audible gap every time the song title changes."
+
 format = " Format "
 
+formats = " Supported Media Formats "
+
 format_info_bar_tip = "Information about how the encoder is currently configured is displayed here."
 
 from_here = "From Here"
@@ -401,12 +415,16 @@ login_tip = "Icecast servers can be configured to have individual per-user sourc
 
 loop_all = "Loop All"
 
+lower_vorbis = "Lower %"
+
 make_public = "Make Public"
 
 make_public_tip = "Publish your radio station on a listings website. The website in question will depend on how the server to which you connect is configured."
 
 manual = "Manual"
 
+mediafilter_all = "Supported media"
+
 message = "Message:"
 
 message_timer_interval = "The time period in minutes between messages. The minimum 1 minute is intended for testing purposes."
@@ -461,6 +479,8 @@ missing_lame = "MP3 Not available"
 
 mixer_crash = "The mixer module crashed during initialisation."
 
+mono = "Mono"
+
 mount_point_tip = "The mount point, which is not required when dealing with Shoutcast servers. A typical mount point might be /listen or /listen.ogg. It is recommended that Ogg streams have a mount point ending in .ogg for the sake of listener client compatibility."
 
 mp3_compat_tip = "The type of mpeg header used in the mp3 stream or either s-rate or freeformat. Freeformat indicates that the bitrate is not specified in the header since it is non-standard, rather the listener client has to figure out what the bitrate is by itself and not all of them are capable of doing that. In short you'll be streaming something many listeners may not be able to listen to. S-rate indicates the sample rate you have selected is not compatible with mp3 and you'll need to change it if you want to stream."
@@ -487,13 +507,13 @@ ng_atten_tip = "This controls the amount of attenuation applied by the noise gat
 
 ng_delay = "Delay"
 
-ng_delay_tip = "This is the number of samples to delay before switching the noise gate on. It's purpose is to make the noise gate ignore very brief pauses in speech. A sensible figure would be 800."
+ng_delay_tip = "This is the number of milliseconds to wait before closing the noise gate. It's purpose is to make the noise gate ignore very brief pauses in speech. A sensible figure would be 18ms."
 
-ng_fall_tip = "This controls how quickly the sound level will fall to the specified attenuation level when the noise gate switches on. Larger numbers = slower. A sensible value would be 500."
+ng_fall_tip = "This controls the speed at which the gate attenuation can increase. The value is a time constant expressed in milliseconds. A sensible value would be 12ms."
 
 ng_hyster_tip = "This setting applies hysteresis to the noise gate so that it does not continuously switch itself on and off. A sensible setting would be 6 but it depends on how variable the noise floor is."
 
-ng_rise_tip = "This is the rise speed with smaller numbers being faster and relates to how quickly the noise gate switches off and allows the full sound level of speech to pass through. A sensible value would be 55."
+ng_rise_tip = "This is the rise speed as a time constant and relates to how quickly the noise gate opens, allowing the full sound level of speech to pass through. A sensible value would be 1.2ms."
 
 ng_thresh_tip = "The noise gate is provided to apply a little audio expansion to soften the initial punchiness that the compressor lends to the audio when silence is broken while at the same time improving the signal to noise ratio. The 'Threshold' setting should be set about 10dB above the noise floor so that the noise gate is active when you are not talking."
 
@@ -503,6 +523,12 @@ nick_entry_tip = "The nick specified here must match at least one of the nicks y
 
 no_more_ask = "Don't ask again"
 
+no_mp3_stream_available = ("MP3 streaming is unavailable,", "and as a consequence", "Shoutcast is also disabled.", "", "Icecast Ogg streaming only.")
+
+no_mp3_stream_available_tip = """Due to concerns over software patents or through oversight, the person or organisation who compiled this program neglected to include support for mp3 encoding.
+ 
+In order to stream mp3 with Shoutcast you need to either locate and install an unrestricted IDJC package or failing that, compile your own from source."""
+
 no_resample = "Use JACK sample rate"
 
 noise_gate = "Noise Gate"
@@ -525,25 +551,13 @@ normrise = "Rise"
 
 off = "Off"
 
-ogg_bitrate_max_tip = "The upper bitrate limit relative to the nominal bitrate. This is an advisory limit and it may be exceeded. The checkbox to the left enables/disables this feature."
+vorbis_bitrate_max_tip = "The upper bitrate limit relative to the nominal bitrate. This is an advisory limit and it may be exceeded. Normally it is safe to leave the upper limit uncapped since the bitrate will be averaged and the listeners have buffers that extend for many seconds. The checkbox enables/disables this feature."
 
-ogg_bitrate_min_tip = "The minimum bitrate in relative terms. For streaming it is recommended that you set a minimum bitrate although setting any upper and lower limits will result in much higher CPU usage and lower sound quality. The checkbox to the left enables/disables this feature."
+vorbis_bitrate_min_tip = "The minimum bitrate in relative percentage terms. For streaming it is recommended that you set a minimum bitrate to ensure correct listener client behaviour however setting any upper or lower limit will result in a significantly higher CPU usage by a factor of at least three, and slightly degraded sound quality. The checkbox enables/disables this feature."
 
-ogg_bitrate_neg_rel = "Min (-rel)"
+vorbis_bitrate_tip = "The nominal Ogg/Vorbis bitrate in kilobits per second."
 
-ogg_bitrate_nominal = "Nominal Bitrate"
-
-ogg_bitrate_pos_rel = "Max (+rel)"
-
-ogg_bitrate_tip = "The nominal Ogg/Vorbis bitrate in kilobits per second."
-
-ogg_maxrate_active_tip = "Turn on maximum bitrate limiting."
-
-ogg_minrate_active_tip = "Turn on minimum bitrate limiting."
-
-ogg_streamtab_tip = """Clicking this tab selects the Ogg/vorbis file format for streaming and contains settings for configuring the vorbis encoder.
- 
-The lack of an mp3 tab alongside this one indicates that this particular build of IDJC was compiled without mp3 support."""
+ogg_streamtab_tip = "Clicking this tab selects the Ogg family of file formats."
 
 open_aux_element = "Switch to Aux input"
 
@@ -585,6 +599,24 @@ playlist1 = "Playlist 1"
 
 playlist2 = "Playlist 2"
 
+playlistfilter_all = "All file types"
+
+playlistfilter_supported = "Playlist types (*.m3u, *.xspf, *.pls)"
+
+playlisttype_expander = "Select File Type "
+
+#playlisttype_expander_extension = "(By Extension)"
+
+#playlisttype_expander_m3u = "(M3U playlist)"
+
+#playlisttype_expander_xspf = "(XSPF playlist)"
+
+playlisttype_extension = (("By Extension", ""), ("M3U playlist", "m3u"), ("XSPF playlist", "xspf"), ("PLS playlist", "pls"))
+
+playlisttype_header1 = "File Type"
+
+playlisttype_header2 = "Extension"
+
 playlist_menu = "Playlist"
 
 playlist_modes_tip = """This sets the playlist mode which defines player behaviour after a track has finished playing.
@@ -731,11 +763,9 @@ server_port = "Port:"
 
 server_type = "Type:"
 
-server_type_icecast = "Icecast"
-
 server_type_icecast2 = "Icecast 2"
 
-server_type_shoutcast = "Shoutcast (mp3 only)"
+server_type_shoutcast = "Shoutcast"
 
 server_type_tip = "IDJC can connect to both Icecast and Shoutcast servers. For this to be successful you need to specify the type of server that you wish to connect to since each type has a different connection protocol."
 
@@ -903,6 +933,8 @@ If this button is greyed out it means that the encoder is not running, or the bi
 
 upon_connection = "Upon connection:"
 
+upper_vorbis = "Upper %"
+
 use = "Use"
 
 using_jack_server = "Using named JACK server: "
@@ -915,6 +947,8 @@ use_mp3_srate_tip = "Use one of the standard mp3 sample rates for the stream."
 
 voip_mixback_volume_control_tip = "The stream volume level to send to the voice over IP connection."
 
+vorbis_streamtab_tip = "This chooses the Ogg/vorbis format for streaming and recording."
+
 vorbis_tag = "Vorbis Tag"
 
 wet_voice_player_tip = "When you click this button the jingle or track selected in the playlist will be looped continuously and will be audible during moments when the main media players are not active. The 'Stream Mon' feature needs to be turned on if the DJ wants to be able to hear it."
