@@ -15,6 +15,8 @@
 #   along with this program in the file entitled COPYING.
 #   If not, see <http://www.gnu.org/licenses/>.
 
+__all__ = ['PopupWindow']
+
 import pygtk
 pygtk.require('2.0')
 import gtk
@@ -35,7 +37,6 @@ class PopupWindow:
       def __init__(self):
          gtk.Window.__init__(self, gtk.WINDOW_POPUP)
          gtk.Window.set_decorated(self, False)
-         gtk.Window.set_border_width(self, 10)
    
    def timeout_callback(self):
       class bugout:
