@@ -25,16 +25,11 @@ import gobject
 
 import os, time, fcntl
 
-from idjc_config import gfext, pkgdatadir, libexecdir, lameenabled
-#from langheader import *
+from idjc_config import *
 from ln_text import ln
 from IDJCfree import int_object
 from IDJCservdialog import *
 
-num_encoders  = 6
-num_streamers = 6
-num_recorders = 2
-
 ENCODER_START=1; ENCODER_STOP=0					# start_stop_encoder constants
 
 class ModuleFrame(gtk.Frame):
@@ -117,7 +112,13 @@ class AutoAction(gtk.HBox):			# widget consiting of a check button and several r
    def get_radio_index(self):
       return self.radio_active
    def set_radio_index(self, value):
-      self.action_lookup[value][0].clicked()
+      try:
+         self.action_lookup[value][0].clicked()
+      except:
+         try:
+            self.action_lookup[0][0].clicked()
+         except:
+            pass
    def __set_sensitive(self, widget):
       boolean = widget.get_active()
       for radio, action in self.action_lookup:
@@ -144,6 +145,66 @@ class AutoAction(gtk.HBox):			# widget consiting of a check button and several r
          radio.show()
          self.action_lookup.append((radio, action))
 
+class FramedSpin(gtk.Frame):
+   """A framed spin button that can be disabled"""
+   def get_value(self):
+      if self.check.get_active():
+         return self.spin.get_value()
+      else:
+         return -1
+   def get_cooked_value(self):
+      if self.check.get_active():
+         return self.spin.get_value() * self.adj_basis.get_value() / 100
+      else:
+         return -1
+   def set_value(self, new_value):
+      self.spin.set_value(new_value)
+   def cb_toggled(self, widget):
+      self.spin.set_sensitive(widget.get_active())
+   def __init__(self, text, adj, adj_basis):
+      self.adj_basis = adj_basis
+      gtk.Frame.__init__(self)
+      self.check = gtk.CheckButton(text)
+      hbox = gtk.HBox()
+      hbox.pack_start(self.check, False, False, 2)
+      self.check.show()
+      self.set_label_widget(hbox)
+      hbox.show()
+      vbox = gtk.VBox()
+      vbox.set_border_width(2)
+      self.spin = gtk.SpinButton(adj)
+      vbox.add(self.spin)
+      self.spin.show()
+      self.spin.set_sensitive(False)
+      self.add(vbox)
+      vbox.show()
+      self.check.connect("toggled", self.cb_toggled)
+
+class SimpleFramedSpin(gtk.Frame):
+   """A framed spin button"""
+   def get_value(self):
+      if self.check.get_active():
+         return self.spin.get_value()
+      else:
+         return -1
+   def set_value(self, new_value):
+      self.spin.set_value(new_value)
+   def __init__(self, text, adj):
+      gtk.Frame.__init__(self)
+      label = gtk.Label(text)
+      hbox = gtk.HBox()
+      hbox.pack_start(label, False, False, 3)
+      label.show()
+      self.set_label_widget(hbox)
+      hbox.show()
+      vbox = gtk.VBox()
+      vbox.set_border_width(2)
+      self.spin = gtk.SpinButton(adj)
+      vbox.add(self.spin)
+      self.spin.show()
+      self.add(vbox)
+      vbox.show()
+
 class MetadataBar(gtk.HBox):
    def send(self, widget):
       utf8meta = self.metadata_entry.get_text().encode("utf-8", "replace").strip()
@@ -156,27 +217,37 @@ class MetadataBar(gtk.HBox):
       for index, checkbutton in enumerate(self.enablers):
          if checkbutton.get_active(): 
             self.source_client_gui.send("tab_id=%d\ndev_type=encoder\nmetaformat=%s\nmetaformat_mp3=%s\ncommand=new_metaformat\n" % (index, utf8meta, mp3meta))
+   
+   def cb_cb(self, widget):
+      for enabler in self.enablers:
+         if enabler.get_active():
+            self.metadata_update_button.set_sensitive(True)
+            break
+      else:
+         self.metadata_update_button.set_sensitive(False)
+         
    def __init__(self, parent, qty, default_text=""):
       self.source_client_gui = parent
-      gtk.HBox.__init__(self, True)
-      self.set_spacing(12)
+      gtk.HBox.__init__(self)
+      self.set_spacing(13)
       left_hbox = gtk.HBox()
-      self.add(left_hbox)
-      left_hbox.show()
       label = gtk.Label(ln.metadata)
       left_hbox.pack_start(label, False, False, 0)
+      self.pack_start(left_hbox, False, False, 0)
+      left_hbox.show()
       label.show()
       self.enablers = []
       for tab in range(qty):
          cb = gtk.CheckButton(str(tab + 1))
          cb.set_active(True)
+         cb.connect("toggled", self.cb_cb)
          self.enablers.append(cb)
-         left_hbox.pack_start(cb, True, False, 0)
+         left_hbox.pack_start(cb, False, False, 0)
          cb.show()
          parent.parent.tooltips.set_tip(cb, ln.metadata_checkbox_tip)
       right_hbox = gtk.HBox()
       right_hbox.set_spacing(5)
-      self.add(right_hbox)
+      self.pack_start(right_hbox, True, True, 0)
       right_hbox.show()
       self.metadata_entry = gtk.Entry()
       self.metadata_entry.set_text("%s")
@@ -225,7 +296,7 @@ class StreamTab(Tab):
          self.resample_quality = ("highest", "high", "fast", "fastest")[self.resample_quality_combo_box.get_active()]
          self.mp3_compatible = self.resample_rate in self.mp3_samplerates
          self.parentobject.mp3_dummy_object.clicked()		# update mp3 pane
-         self.parentobject.ogg_dummy_object.clicked()
+         self.parentobject.vorbis_dummy_object.clicked()
       def __init__(self, parent, sizegroup):
          self.parentobject = parent
          self.jack_sample_rate = parent.source_client_gui.jack_sample_rate
@@ -242,7 +313,7 @@ class StreamTab(Tab):
          self.resample_rate_combo_box = self.parentobject.make_combo_box(map(str, self.mp3_samplerates))
          self.resample_rate_combo_box.set_active(1)
          self.resample_rate_combo_box.connect("changed", self.cb_eval)
-         self.resample_rate_spin_adj = gtk.Adjustment(44100, 4000, 96000, 10, 100, 0)
+         self.resample_rate_spin_adj = gtk.Adjustment(44100, 4000, 190000, 10, 100, 0)
          self.resample_rate_spin_control = gtk.SpinButton(self.resample_rate_spin_adj, 0, 0)
          self.resample_rate_spin_control.connect("value-changed", self.cb_eval)
          resample_quality_label = gtk.Label(ln.resample_quality)
@@ -276,6 +347,13 @@ class StreamTab(Tab):
          if iteration > 0:
             listofradiobuttons[iteration].set_group(listofradiobuttons[0])
       return listofradiobuttons
+   def make_radio_with_text(self, labels):
+      listofradiobuttons = []
+      for count, label in enumerate(labels):
+         listofradiobuttons.append(gtk.RadioButton(None, label))
+         if count > 0:
+            listofradiobuttons[count].set_group(listofradiobuttons[0])
+      return listofradiobuttons
    def make_notebook_tab(self, notebook, labeltext, tooltip = None):
       label = gtk.Label(labeltext)
       if tooltip is not None:
@@ -307,6 +385,7 @@ class StreamTab(Tab):
       vbox.set_spacing(2)
       for left, right in item_item_pairs:
          hbox = gtk.HBox()
+         rhs_size.add_widget(left)
          sizegroup.add_widget(hbox)
          hbox.set_spacing(5)
          hbox.pack_start(left, False, False, 0)
@@ -318,6 +397,39 @@ class StreamTab(Tab):
          vbox.pack_start(hbox, False, False, 0)
          hbox.show()
       return vbox
+   def item_item_layout3(self, leftitems, rightitems):
+      outer = gtk.HBox()
+      wedge = gtk.HBox()
+      outer.pack_start(wedge, False, False, 2)
+      wedge = gtk.HBox()
+      outer.pack_end(wedge, False, False, 2)
+      lh = gtk.HBox()
+      rh = gtk.HBox()
+      outer.pack_start(lh, True, False, 0)
+      outer.pack_start(rh, True, False, 0)
+      lv = gtk.VBox()
+      rv = gtk.VBox()
+      lh.pack_start(lv, False, False, 0)
+      rh.pack_start(rv, False, False, 0)
+      lframe = gtk.Frame()
+      lframe.set_shadow_type(gtk.SHADOW_OUT)
+      rframe = gtk.Frame()
+      rframe.set_shadow_type(gtk.SHADOW_OUT)
+      lv.pack_start(lframe, True, False, 0)
+      rv.pack_start(rframe, True, False, 0)
+      lvi = gtk.VBox()
+      lvi.set_border_width(5)
+      lvi.set_spacing(7)
+      rvi = gtk.VBox()
+      rvi.set_border_width(5)
+      rvi.set_spacing(7)
+      lframe.add(lvi)
+      rframe.add(rvi)
+      for item in leftitems:
+         lvi.pack_start(item, True, False, 0)
+      for item in rightitems:
+         rvi.pack_start(item, True, False, 0)
+      return outer
    def label_item_layout(self, label_item_pairs, sizegroup):	# align vertical colums of label : item
       hbox = gtk.HBox()						# label is right justified and narrow as possible
       vbox_left = gtk.VBox()					# the item widget is free to expand
@@ -364,7 +476,7 @@ class StreamTab(Tab):
          if self.format_page == 0:
             self.update_button.set_sensitive(False)
          elif self.format_page == 1:
-           self.update_button.set_sensitive(self.ogg_settings_valid)
+           self.update_button.set_sensitive(self.vorbis_settings_valid)
          elif self.format_page == 2:
             try:
                self.update_button.set_sensitive(self.file_dialog.get_filename().lower().endswith(".ogg"))
@@ -388,11 +500,17 @@ class StreamTab(Tab):
       elif self.encoder == "off":
          self.test_monitor.set_sensitive(True)
          if self.format_page == 0:
-            sens = self.mp3_compatibility != "s-rate!" and True or False
+            sens = bool(self.mp3_compatibility != "s-rate!" and lameenabled)
             self.server_connect.set_sensitive(sens)
             self.test_monitor.set_sensitive(sens)
          elif self.format_page == 1:
-            self.recorder_valid_override = sens = self.ogg_settings_valid
+            if self.subformat_page == 0:
+               self.recorder_valid_override = sens = self.vorbis_settings_valid
+            elif self.subformat_page == 1:   # OggFLAC
+               sr = self.stream_resample_frame.resample_rate
+               sens = sr <= 65535 or sr % 10 == 0
+            elif self.subformat_page == 2:   # Speex
+               sens = True                   # True always for now
             self.server_connect.set_sensitive(sens and non_shoutcast or self.server_connect.get_active())
             self.test_monitor.set_sensitive(sens)
          elif self.format_page == 2:
@@ -428,6 +546,10 @@ class StreamTab(Tab):
       if self.format_page != page_num:
          self.format_page = page_num
          self.update_sensitives()
+   def cb_subformat_notebook(self, widget, page, page_num):
+      if self.subformat_page != page_num:
+         self.subformat_page = page_num
+         self.update_sensitives()
    def cb_mp3tab(self, widget, data = None):
       if data == "standard" or data == "custom":
          if widget.get_active():
@@ -456,6 +578,7 @@ class StreamTab(Tab):
       self.mp3_compatibility_status.push(1, self.mp3_compatibility)
       self.mp3_freeformat = ("0", "1")[self.mp3_compatibility == "freeformat"]
       self.update_sensitives()
+   
    def cb_oggtab(self, widget, data = None):
       ogg_bitrate = self.ogg_encoding_nominal_spin_adj.get_value()
       minactive = self.ogg_min_checkbutton.get_active()
@@ -475,8 +598,19 @@ class StreamTab(Tab):
       self.send("sample_rate=%d\nbit_rate=%d\nbit_rate_min=%d\nbit_rate_max=%d\nstereo=%s\ncommand=test_ogg_values\n" % (self.stream_resample_frame.resample_rate, 
          	ogg_bitrate, ogg_min, ogg_max,
                 ("mono","stereo")[self.ogg_encoding_stereo_checkbutton.get_active()]))
-      self.ogg_settings_valid = self.receive() == "succeeded"
+      self.vorbis_settings_valid = self.receive() == "succeeded"
       self.update_sensitives()
+      
+   def cb_vorbistab(self, widget, data = None):
+      vorbis_bitrate = self.vorbis_encoding_nominal_spin_adj.get_value()
+      vorbis_min = self.vorbis_encoding_lower_spin_control.get_cooked_value()
+      vorbis_max = self.vorbis_encoding_upper_spin_control.get_cooked_value()
+      self.send("sample_rate=%d\nbit_rate=%d\nbit_rate_min=%d\nbit_rate_max=%d\nstereo=%s\ncommand=test_ogg_values\n" % (self.stream_resample_frame.resample_rate, 
+         	vorbis_bitrate, vorbis_min, vorbis_max,
+                ("mono","stereo")[self.vorbis_stereo_rb.get_active()]))
+      self.vorbis_settings_valid = self.receive() == "succeeded"
+      self.update_sensitives()
+      
    def mpeg_std_search(self, bitrate, samplerate, brsr):
       return bitrate in brsr[0] and samplerate in brsr[1]
    def server_reconnect(self):
@@ -490,7 +624,7 @@ class StreamTab(Tab):
       if widget.get_active():
          self.start_stop_encoder(ENCODER_START)
          self.connection_string = "\n".join((    "stream_source=" + str(self.numeric_id),
-         			  "server_type=" + self.server_type_dropdown.get_active_text(),
+         			  "server_type=" + ("Shoutcast", "Icecast 2") [self.server_type_dropdown.get_active()],
       				  "host=" + self.host_entry.get_text().strip(),
                                   "port=" + str(self.port_adj.get_value()),
       				  "mount=" + self.mount_entry.get_text().strip(),
@@ -549,26 +683,33 @@ class StreamTab(Tab):
             self.format_info_bar.push(1, "")
       elif self.format_page == 1:
          self.encoder = "ogg"
-         ogg_bitrate = self.ogg_encoding_nominal_spin_adj.get_value()
-         if self.ogg_min_checkbutton.get_active():
-            ogg_min = self.ogg_encoding_relmin_spin_adj.get_value() + ogg_bitrate
-            if ogg_min <= 0:
-               ogg_min = -1
-         else:
-            ogg_min = -1
-         if self.ogg_max_checkbutton.get_active():
-            ogg_max = self.ogg_encoding_relmax_spin_adj.get_value() + ogg_bitrate
-         else:
-            ogg_max = -1
-         ogg_channels = ("mono", "stereo")[self.ogg_encoding_stereo_checkbutton.get_active()]
-         self.send("format=ogg\nencode_source=jack\nsample_rate=%d\nresample_quality=%s\nbit_rate=%d\nbit_rate_min=%d\nbit_rate_max=%d\nstereo=%s\ncommand=%s\n" % (self.stream_resample_frame.resample_rate, 
-         				  self.stream_resample_frame.resample_quality,
-                                          ogg_bitrate, ogg_min, ogg_max,
-                                          ogg_channels, command))
-         if self.receive() == "succeeded":
-            self.format_info_bar.push(1, "Ogg   %dHz   %dkbps   %s" % (self.stream_resample_frame.resample_rate, ogg_bitrate, ogg_channels))
-         else:
-            self.format_info_bar.push(1, "")
+         if self.subformat_page == 0:  # vorbis
+            vorbis_bitrate = self.vorbis_encoding_nominal_spin_adj.get_value()
+            vorbis_min = self.vorbis_encoding_lower_spin_control.get_cooked_value()
+            vorbis_max = self.vorbis_encoding_upper_spin_control.get_cooked_value()
+            vorbis_channels = ("mono", "stereo")[self.vorbis_stereo_rb.get_active()]
+            self.send("format=ogg\nsubformat=vorbis\nencode_source=jack\nsample_rate=%d\nresample_quality=%s\nbit_rate=%d\nbit_rate_min=%d\nbit_rate_max=%d\nstereo=%s\ncommand=%s\n" % (self.stream_resample_frame.resample_rate, 
+                                             self.stream_resample_frame.resample_quality,
+                                             vorbis_bitrate, vorbis_min, vorbis_max,
+                                             vorbis_channels, command))
+            if self.receive() == "succeeded":
+               if vorbis_min == vorbis_max == -1:
+                  managed = ""
+               else:
+                  managed = "   managed"
+               self.format_info_bar.push(1, "Ogg Vorbis   %dHz   %dkbps   %s%s" % (self.stream_resample_frame.resample_rate, vorbis_bitrate, vorbis_channels, managed))
+            else:
+               self.format_info_bar.push(1, "")
+         elif self.subformat_page == 1: # OggFLAC
+            flac_channels = ("mono", "stereo")[self.flacstereo.get_active()]
+            flac_bitwidth = ("16", "20", "24")[(self.flac20bit.get_active() and 1) + (self.flac24bit.get_active() and 2)]
+            self.send("format=ogg\nsubformat=flac\nencode_source=jack\nsample_rate=%d\nresample_quality=%s\nbit_width=%s\nstereo=%s\nuse_metadata=%d\ncommand=%s\n" % (self.stream_resample_frame.resample_rate, self.stream_resample_frame.resample_quality, flac_bitwidth, flac_channels, self.flacmetadata.get_active(), command))
+            if self.receive() == "succeeded":
+               self.format_info_bar.push(1, "Ogg FLAC   %s bit   %s" % (flac_bitwidth, flac_channels))
+            else:
+               self.format_info_bar.push(1, "")
+         elif self.subformat_page == 2: # speex
+            pass
       else:
          if self.file_dialog.get_filename().endswith(".mp3"):
             self.encoder = "mp3"
@@ -585,6 +726,14 @@ class StreamTab(Tab):
       if self.receive() == "failed":
          print "stop_encoder: encoder was already stopped"
       self.format_info_bar.push(1, "")
+   
+   def server_type_cell_data_func(self, celllayout, cell, model, iter):
+      text = model.get_value(iter, 0)
+      if text == ln.server_type_shoutcast and lameenabled == 0:
+         cell.set_property("sensitive", False)
+      else:
+         cell.set_property("sensitive", True)
+   
    def __init__(self, scg, numeric_id, indicator_lookup):
       Tab.__init__(self, scg, numeric_id, indicator_lookup)
       self.scg = scg
@@ -593,11 +742,12 @@ class StreamTab(Tab):
       self.encoder = "off"			# can also be set to "mp3" or "ogg" depending on what is encoded
       self.encoder_on_count = 0			# when this counter hits zero the encoder is turned off
       self.format_page = 0			# the current format page
+      self.subformat_page = 0                   # the Ogg sub-format
       Tab.set_spacing(self, 10)
       scrolled = gtk.ScrolledWindow()
       Tab.add(self, scrolled)
       scrolled.show()
-      scrolled.set_size_request(-1, 162)
+      scrolled.set_size_request(-1, 355)
       scrolled.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
       scrolled.set_shadow_type(gtk.SHADOW_NONE)
       scrolled_vbox = gtk.VBox()
@@ -609,10 +759,15 @@ class StreamTab(Tab):
       scrolled_vbox.pack_start(frame, False, False, 0)
       frame.show()
       sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_VERTICAL)
-      self.server_type_dropdown = gtk.combo_box_new_text()
+      
+      ls = gtk.ListStore(str)
+      self.server_type_dropdown = gtk.ComboBox(ls)
+      cell = gtk.CellRendererText()
+      self.server_type_dropdown.pack_start(cell, True)
+      self.server_type_dropdown.add_attribute(cell, 'text', 0)
+      self.server_type_dropdown.set_cell_data_func(cell, self.server_type_cell_data_func)
       self.server_type_dropdown.append_text(ln.server_type_shoutcast)
       self.server_type_dropdown.append_text(ln.server_type_icecast2)
-      self.server_type_dropdown.append_text(ln.server_type_icecast)
       self.server_type_dropdown.set_active(1)
       self.server_type_dropdown.connect("changed", self.cb_servertype)
       set_tip = scg.parent.tooltips.set_tip
@@ -708,53 +863,90 @@ class StreamTab(Tab):
       self.mp3_dummy_object.connect("clicked", self.cb_mp3tab)
       self.mp3_bitrate = 128
       self.mp3_bitrate_widget = "standard"
-      mp3_pane = self.item_item_layout(((self.standard_mp3_bitrate, self.mp3_bitrate_combo_box),
-      					(self.custom_mp3_bitrate, self.mp3_bitrate_spin_control),
-                                        (encoding_quality_label, self.mp3_encoding_quality_combo_box),
-                                        (self.mp3_stereo_combo_box, self.mp3_compatibility_status)), sizegroup)
-      mp3_pane.set_border_width(10)
+      
+      if lameenabled:
+         mp3_pane = self.item_item_layout(((self.standard_mp3_bitrate, self.mp3_bitrate_combo_box),
+                                       (self.custom_mp3_bitrate, self.mp3_bitrate_spin_control),
+                                       (encoding_quality_label, self.mp3_encoding_quality_combo_box),
+                                       (self.mp3_stereo_combo_box, self.mp3_compatibility_status)), sizegroup)
+         mp3_pane.set_border_width(10)
+      else:
+         mp3_pane = gtk.VBox(True)
+         for line in ln.no_mp3_stream_available:
+            label = gtk.Label(line)
+            mp3_pane.add(label)
+            label.show()
+         set_tip(mp3_pane, ln.no_mp3_stream_available_tip)
+      
       self.mp3tab.add(mp3_pane)
       mp3_pane.show()
-      if not lameenabled:
-         self.mp3tab.hide()
 
       # Ogg tab
       self.oggtab = self.make_notebook_tab(self.format_notebook, "Ogg", ln.ogg_streamtab_tip)
-      nominal_label = gtk.Label(ln.ogg_bitrate_nominal)
-      self.ogg_encoding_nominal_spin_adj = gtk.Adjustment(128, 45, 500, 1, 10, 0)
-      self.ogg_encoding_nominal_spin_control = gtk.SpinButton(self.ogg_encoding_nominal_spin_adj)
-      self.ogg_encoding_nominal_spin_control.connect("value-changed", self.cb_oggtab)
-      self.ogg_min_checkbutton = gtk.CheckButton(ln.ogg_bitrate_neg_rel)
-      self.ogg_min_checkbutton.connect("clicked", self.cb_oggtab)
-      self.ogg_encoding_relmin_spin_adj = gtk.Adjustment(0, -400, 0, 1, 10, 0)
-      self.ogg_encoding_relmin_spin_control = gtk.SpinButton(self.ogg_encoding_relmin_spin_adj)
-      self.ogg_encoding_relmin_spin_control.set_sensitive(False)
-      self.ogg_encoding_relmin_spin_control.connect("value-changed", self.cb_oggtab)
-      self.ogg_max_checkbutton = gtk.CheckButton(ln.ogg_bitrate_pos_rel)
-      self.ogg_max_checkbutton.connect("clicked", self.cb_oggtab)
-      self.ogg_encoding_relmax_spin_adj = gtk.Adjustment(0, 0, 400, 1, 10, 0)
-      self.ogg_encoding_relmax_spin_control = gtk.SpinButton(self.ogg_encoding_relmax_spin_adj)
-      self.ogg_encoding_relmax_spin_control.set_sensitive(False)
-      self.ogg_encoding_relmax_spin_control.connect("value-changed", self.cb_oggtab)
-      self.ogg_encoding_stereo_checkbutton = gtk.CheckButton(ln.stereo)
-      self.ogg_encoding_stereo_checkbutton.set_active(True)
-      self.ogg_encoding_stereo_checkbutton.connect("clicked", self.cb_oggtab)
-      ogg_pane = self.item_item_layout2(((nominal_label, self.ogg_encoding_nominal_spin_control),
-      					(self.ogg_min_checkbutton, self.ogg_encoding_relmin_spin_control),
-                                        (self.ogg_max_checkbutton, self.ogg_encoding_relmax_spin_control),
-                                        (self.ogg_encoding_stereo_checkbutton,
-                                        None)), sizegroup)
-      set_tip(self.ogg_encoding_nominal_spin_control.get_parent(), ln.ogg_bitrate_tip)
-      set_tip(self.ogg_encoding_relmin_spin_control.get_parent(), ln.ogg_bitrate_min_tip)
-      set_tip(self.ogg_encoding_relmax_spin_control.get_parent(), ln.ogg_bitrate_max_tip)
-      set_tip(self.ogg_min_checkbutton, ln.ogg_minrate_active_tip)
-      set_tip(self.ogg_max_checkbutton, ln.ogg_maxrate_active_tip)
-      ogg_pane.set_border_width(10)
-      self.oggtab.add(ogg_pane)
-      ogg_pane.show()
-      self.ogg_settings_valid = False
-      self.ogg_dummy_object = gtk.Button()
-      self.ogg_dummy_object.connect("clicked", self.cb_oggtab)
+      self.subformat_notebook = gtk.Notebook()
+      self.oggtab.add(self.subformat_notebook)
+      self.subformat_notebook.show()
+      self.oggvorbistab = self.make_notebook_tab(self.subformat_notebook, "Vorbis", ln.vorbis_streamtab_tip)
+      self.oggflactab = self.make_notebook_tab(self.subformat_notebook, "FLAC", ln.flac_streamtab_tip)
+      
+      # Vorbis subtab contents
+      self.vorbis_encoding_nominal_spin_adj = gtk.Adjustment(128, 45, 500, 1, 10, 0)
+      self.vorbis_encoding_nominal_spin_control = SimpleFramedSpin(ln.bitrate, self.vorbis_encoding_nominal_spin_adj)
+      self.vorbis_encoding_nominal_spin_control.spin.connect("value-changed", self.cb_vorbistab)
+      
+      self.vorbis_stereo_rb, self.vorbis_mono_rb = self.make_radio(2)
+      self.vorbis_stereo_rb.connect("toggled", self.cb_vorbistab)
+      radiovbox = gtk.VBox()
+      radiovbox.set_border_width(5)
+      stereohbox = gtk.HBox()
+      monohbox = gtk.HBox()
+      radiovbox.add(stereohbox)
+      radiovbox.add(monohbox)
+      stereohbox.pack_start(self.vorbis_stereo_rb, False, False, 0)
+      monohbox.pack_start(self.vorbis_mono_rb, False, False, 0)
+      label = gtk.Label(ln.stereo)
+      stereohbox.pack_start(label)
+      label = gtk.Label(ln.mono)
+      monohbox.pack_start(label)
+      radiovbox.show_all()
+      
+      upper_spin_adj = gtk.Adjustment(150, 100, 400, 1, 10, 0)
+      lower_spin_adj = gtk.Adjustment(50, 0, 100, 1, 10, 0)
+      self.vorbis_encoding_upper_spin_control = FramedSpin(ln.upper_vorbis, upper_spin_adj, self.vorbis_encoding_nominal_spin_adj)
+      self.vorbis_encoding_lower_spin_control = FramedSpin(ln.lower_vorbis, lower_spin_adj, self.vorbis_encoding_nominal_spin_adj)
+      
+      sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_VERTICAL)
+
+      vorbis_pane = self.item_item_layout2(((self.vorbis_encoding_nominal_spin_control, self.vorbis_encoding_upper_spin_control), (radiovbox, self.vorbis_encoding_lower_spin_control)), sizegroup)
+      vorbis_pane.set_border_width(3)
+      self.oggvorbistab.add(vorbis_pane)
+      vorbis_pane.show()
+
+      set_tip(self.vorbis_encoding_nominal_spin_control, ln.vorbis_bitrate_tip)
+      set_tip(self.vorbis_encoding_upper_spin_control, ln.vorbis_bitrate_max_tip)
+      set_tip(self.vorbis_encoding_lower_spin_control, ln.vorbis_bitrate_min_tip)
+
+      self.vorbis_settings_valid = False
+      self.vorbis_dummy_object = gtk.Button()
+      self.vorbis_dummy_object.connect("clicked", self.cb_vorbistab)
+
+      # FLAC subtab contents
+      self.flacstereo = gtk.CheckButton(ln.stereo)
+      self.flacmetadata = gtk.CheckButton(ln.flacmetadata)
+      self.flacstereo.set_active(True)
+      self.flacmetadata.set_active(True)
+      set_tip(self.flacmetadata, ln.flacmetadata_tip)
+      
+      self.flac16bit, self.flac20bit, self.flac24bit = self.make_radio_with_text(ln.flac_bitrates)
+      set_tip(self.flac16bit, ln.flac16_tip)
+      set_tip(self.flac20bit, ln.flac20_tip)
+      set_tip(self.flac24bit, ln.flac24_tip)
+      if oggflacenabled:
+         flac_pane = self.item_item_layout3((self.flacstereo, self.flacmetadata),(self.flac16bit, self.flac20bit, self.flac24bit))
+      else:
+         flac_pane = gtk.Label(ln.feature_disabled)
+      self.oggflactab.add(flac_pane)
+      flac_pane.show_all()
       
       self.filetab = self.make_notebook_tab(self.format_notebook, "File")	# File tab
       filefilter = gtk.FileFilter()
@@ -811,6 +1003,7 @@ class StreamTab(Tab):
       format_control_bar.pack_start(self.update_button, False, False, 0)
       self.update_button.show()
       self.format_notebook.connect("switch-page", self.cb_format_notebook)
+      self.subformat_notebook.connect("switch-page", self.cb_subformat_notebook)
       self.format_notebook.set_current_page(0)
       frame = ModuleFrame(ln.stream_info)		# frame containing stream information (optional)
       scrolled_vbox.pack_start(frame, False, False, 0)
@@ -871,14 +1064,16 @@ class StreamTab(Tab):
       hbox.pack_start(self.start_player_action, False, False, 0)
       self.start_player_action.show()
       set_tip(self.start_player_action, ln.auto_start_player_tip)
-      vseparator = gtk.VSeparator()
-      hbox.pack_start(vseparator, True, False, 0)
-      vseparator.show()
-      self.start_recorder_action = AutoAction(ln.start_recorder, (
-         ("1", self.source_client_gui.recordtabframe.tabs[0].record_buttons.record_button.activate),
-         ("2", self.source_client_gui.recordtabframe.tabs[1].record_buttons.record_button.activate)))
+      if num_recorders:
+         vseparator = gtk.VSeparator()
+         hbox.pack_start(vseparator, True, False, 0)
+         vseparator.show()
+      
+      self.start_recorder_action = AutoAction(ln.start_recorder, [ (chr(ord("1") + i), t.record_buttons.record_button.activate) for i, t in enumerate(self.source_client_gui.recordtabframe.tabs) ])
+      
       hbox.pack_end(self.start_recorder_action, False, False, 0)
-      self.start_recorder_action.show()
+      if num_recorders:
+         self.start_recorder_action.show()
       set_tip(self.start_recorder_action, ln.auto_start_recorder_tip)
       Tab.pack_start(self, hbox, False, False, 0)
       hbox.show()
@@ -896,18 +1091,23 @@ class StreamTab(Tab):
                         "rs_custom_rate" : (self.stream_resample_frame.resample_rate_spin_adj, "value"),
                         "rs_quality" : (self.stream_resample_frame.resample_quality_combo_box, "active"),
                         "source_type" : (self.format_notebook, "notebookpage"),
+                        "ogg_type": (self.subformat_notebook, "notebookpage"),
                         "std_mp3bitrate" : (self.standard_mp3_bitrate, "active"),
                         "custom_mp3_bitrate" : (self.custom_mp3_bitrate, "active"),
                         "mp3_bitrate_combo" : (self.mp3_bitrate_combo_box, "active"),
                         "mp3_bitrate_spin" : (self.mp3_bitrate_spin_adj, "value"),
                         "mp3_quality" : (self.mp3_encoding_quality_combo_box, "active"),
                         "mp3_stereo" : (self.mp3_stereo_combo_box, "active"),
-                        "ogg_bitrate" : (self.ogg_encoding_nominal_spin_adj, "value"),
-                        "ogg_use_min" : (self.ogg_min_checkbutton, "active"),
-                        "ogg_min_bitrate" : (self.ogg_encoding_relmin_spin_adj, "value"),
-                        "ogg_use_max" : (self.ogg_max_checkbutton, "active"),
-                        "ogg_max_bitrate" : (self.ogg_encoding_relmax_spin_adj, "value"),
-                        "ogg_stereo" : (self.ogg_encoding_stereo_checkbutton, "active"),
+                        "vorbis_bitrate" : (self.vorbis_encoding_nominal_spin_adj, "value"),
+                        "vorbis_upper_pc": (self.vorbis_encoding_upper_spin_control.spin, "value"),
+                        "vorbis_lower_pc":  (self.vorbis_encoding_lower_spin_control.spin, "value"),
+                        "vorbis_upper_enable": (self.vorbis_encoding_upper_spin_control.check, "active"),
+                        "vorbis_lower_enable": (self.vorbis_encoding_lower_spin_control.check, "active"),
+                        "vorbis_mono": (self.vorbis_mono_rb, "active"),
+                        "flac_stereo": (self.flacstereo, "active"),
+                        "flac_metadata": (self.flacmetadata, "active"),
+                        "flac_20_bit": (self.flac20bit, "active"),
+                        "flac_24_bit": (self.flac24bit, "active"),
                         "file_source" : (self.file_dialog, "filename"),
                         "file_use_offset" : (self.file_offset_checkbutton, "active"),
                         "file_offset" : (self.file_offset_adj, "value"),
@@ -938,6 +1138,7 @@ class RecordTab(Tab):
                          		self.parentobject.source_dest.file_dialog.get_current_folder()))
                   self.parentobject.source_dest.file_dialog.response(gtk.RESPONSE_CLOSE)
                   self.parentobject.source_dest.set_sensitive(False)
+                  self.parentobject.time_indicator.set_sensitive(True)
                   self.recording = True
                   if self.parentobject.receive() == "failed":
                      self.stop_button.clicked()
@@ -950,6 +1151,7 @@ class RecordTab(Tab):
                      self.parentobject.receive()
                   self.parentobject.source_dest.streamtab.start_stop_encoder(ENCODER_STOP)
                   self.parentobject.source_dest.set_sensitive(True)
+                  self.parentobject.time_indicator.set_sensitive(False)
                   if self.pause_button.get_active():
                      self.pause_button.set_active(False)
                else:
@@ -1009,13 +1211,17 @@ class RecordTab(Tab):
                self.set_text("%dd:%02d:%02d" % (days, hours, minutes))
             else:
                self.set_text("%02d:%02d:%02d" % (hours, minutes, seconds))
+      def button_press_cancel(self, widget, event):
+         return True
       def __init__(self, parent):
          self.parentobject = parent
          gtk.Entry.__init__(self)
          self.set_width_chars(7)
          self.set_sensitive(False)
+         self.set_editable(False)
          self.oldvalue = -1
          self.set_value(0)
+         self.connect("button-press-event", self.button_press_cancel)
          parent.scg.parent.tooltips.set_tip(self, ln.recording_time_tip)
    class SourceDest(CategoryFrame):
       cansave = False
@@ -1182,7 +1388,7 @@ class SourceClientGui:
             fcntl.flock(file.fileno(), fcntl.LOCK_UN)
             file.close()
          except IOError:
-            print "Problem writing the timer file to disk"           
+            print "Problem writing the timer file to disk"
       gtk.gdk.threads_leave()
       return True
    def stop_streaming_all(self):
@@ -1460,13 +1666,14 @@ class SourceClientGui:
       self.streamtabframe.set_sensitive(True)
       vbox.pack_start(self.streamtabframe, True, True, 0)
       self.streamtabframe.show()
-      metabar = MetadataBar(self, 6, "%s")
+      metabar = MetadataBar(self, num_encoders, "%s")
       vbox.pack_start(metabar, False, False, 0)
       metabar.show()
       for rectab in self.recordtabframe.tabs:
          rectab.source_dest.populate_stream_selector(ln.stream, self.streamtabframe.tabs)
       vbox.pack_start(self.recordtabframe, False, False, 0)
-      self.recordtabframe.show()
+      if num_recorders:
+         self.recordtabframe.show()
       vbox.show()
       self.tabs = (self, )			#
       self.numeric_id = 0			# pretend to be a tabframe and its tab for save/load purposes
@@ -1487,3 +1694,4 @@ class SourceClientGui:
       self.autoshutdown_dialog = error_notification_dialog(self.dialog_group, self.parent.window_group, ln.disconnected, ln.autoshutdown)
       
       self.monitor_source_id = gobject.timeout_add(250, self.monitor)
+      self.window.realize()   # prevent rendering bug and problems with sizegroups on certain widgets
